<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="17"/>
        <source>Account details</source>
        <translation>Detalles de la cuenta</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="35"/>
        <location filename="../src/accountdetailsdialog.cpp" line="74"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="39"/>
        <location filename="../src/accountdetailsdialog.cpp" line="76"/>
        <source>Default budget</source>
        <translation>Presupuesto por defecto</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="42"/>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="44"/>
        <location filename="../src/accountdetailsdialog.cpp" line="79"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="46"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="61"/>
        <source>Create new account</source>
        <translation>Crear nueva cuenta</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="90"/>
        <location filename="../src/accountdetailsdialog.cpp" line="126"/>
        <source>Default budget cannot be empty</source>
        <translation>El presupuesto no puede estar vacío</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="97"/>
        <location filename="../src/accountdetailsdialog.cpp" line="133"/>
        <source>Invalid budget format</source>
        <translation>Formato del presupuesto inválido</translation>
    </message>
    <message>
        <location filename="../src/accountdetailsdialog.cpp" line="121"/>
        <source>Name field cannot be empty</source>
        <translation>El campo nombre no puede estar vacío</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <location filename="../src/accountsdialog.cpp" line="13"/>
        <source>Accounts</source>
        <translation>Cuentas</translation>
    </message>
    <message>
        <location filename="../src/accountsdialog.cpp" line="27"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
</context>
<context>
    <name>BudgetDialog</name>
    <message>
        <location filename="../src/budgetdialog.cpp" line="14"/>
        <source>Modify month budget</source>
        <translation>Modificar presupuesto mensual</translation>
    </message>
    <message>
        <location filename="../src/budgetdialog.cpp" line="23"/>
        <source>Month budget</source>
        <translation>Presupuesto mensual</translation>
    </message>
    <message>
        <location filename="../src/budgetdialog.cpp" line="26"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/budgetdialog.cpp" line="39"/>
        <source>Invalid amount format</source>
        <translation>Formato inválido para cantidad</translation>
    </message>
</context>
<context>
    <name>ConceptDetailsDialog</name>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="17"/>
        <source>Item details</source>
        <translation>Detalles de concepto</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="30"/>
        <location filename="../src/conceptdetailsdialog.cpp" line="67"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="35"/>
        <location filename="../src/conceptdetailsdialog.cpp" line="69"/>
        <source>Price</source>
        <translation>Precio</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="38"/>
        <location filename="../src/conceptdetailsdialog.cpp" line="72"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="40"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="54"/>
        <source>Create new item</source>
        <translation>Crear nuevo concepto</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="83"/>
        <location filename="../src/conceptdetailsdialog.cpp" line="113"/>
        <source>Price field cannot be empty</source>
        <translation>El campo precio no puede estar vacío</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="90"/>
        <location filename="../src/conceptdetailsdialog.cpp" line="120"/>
        <source>Invalid price format</source>
        <translation>Formato inválido para precio</translation>
    </message>
    <message>
        <location filename="../src/conceptdetailsdialog.cpp" line="108"/>
        <source>Name field cannot be empty</source>
        <translation>El campo nombre no puede estar vacío</translation>
    </message>
</context>
<context>
    <name>ConceptsChart</name>
    <message>
        <location filename="../src/conceptschart.cpp" line="154"/>
        <source>No item</source>
        <translation>Sin concepto</translation>
    </message>
</context>
<context>
    <name>ConceptsDialog</name>
    <message>
        <location filename="../src/conceptsdialog.cpp" line="13"/>
        <source>Items</source>
        <translation>Conceptos</translation>
    </message>
    <message>
        <location filename="../src/conceptsdialog.cpp" line="27"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
</context>
<context>
    <name>ConfirmationDialog</name>
    <message>
        <location filename="../src/confirmationdialog.cpp" line="14"/>
        <source>Confirm action</source>
        <translation>Confirmar acción</translation>
    </message>
    <message>
        <location filename="../src/confirmationdialog.cpp" line="23"/>
        <source>Yes</source>
        <translation>Sí</translation>
    </message>
    <message>
        <location filename="../src/confirmationdialog.cpp" line="24"/>
        <source>No</source>
        <translation>No</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../src/controller.cpp" line="39"/>
        <source>You must create an account to be able to write down expenses</source>
        <translation>Debe crear una cuenta para poder almacenar gastos</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="47"/>
        <source>There&apos;s no valid account selected</source>
        <translation>No hay una cuenta válida seleccionada</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="86"/>
        <location filename="../src/controller.cpp" line="100"/>
        <location filename="../src/controller.cpp" line="220"/>
        <location filename="../src/controller.cpp" line="242"/>
        <location filename="../src/controller.cpp" line="294"/>
        <location filename="../src/controller.cpp" line="392"/>
        <location filename="../src/controller.cpp" line="496"/>
        <source>An account must be selected to perform this action</source>
        <translation>Es necesaria una cuenta selecionada para poder realizar esta acción</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="111"/>
        <source>Already at current month</source>
        <translation>Ya está en el mes actual</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="132"/>
        <source>Error creating account</source>
        <translation>Error creando cuenta</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="135"/>
        <source>Account already exists</source>
        <translation>La cuenta ya existe</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="167"/>
        <source>Cannot delete active account</source>
        <translation>No se puede borrar la cuenta activa</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="172"/>
        <source>When deleting an account, all the expenses associated to it will also be deleted
Are you sure you want to delete the account?</source>
        <translation>Al borrar una cuenta, los gastos asociados a ella
        también serán borrados.
¿Está seguro de querer borrar la cuenta?</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="179"/>
        <source>Error deleting account</source>
        <translation>Error borrando la cuenta</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="190"/>
        <source>Error updating account</source>
        <translation>Error actualizando la cuenta</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="272"/>
        <source>Error deleting expense</source>
        <translation>Error eliminando gasto</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="283"/>
        <source>Error updating expense</source>
        <translation>Error actualizando gasto</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="351"/>
        <source>Error creating concept</source>
        <translation>Error creando concepto</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="354"/>
        <source>Concept already exists</source>
        <translation>El concepto ya existe</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="361"/>
        <source>When deleting a concept, all the expenses associated to it will be assigned an empty concept instead.
Are you sure you want to delete the concept?</source>
        <translation>Al eliminar un concepto, a todos los gastos asociados a ese concepto se les asignará un concepto vacío en su lugar.
¿Está seguro de que desea eliminar el concepto?</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="370"/>
        <source>Error deleting concept</source>
        <translation>Error eliminando concepto</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="381"/>
        <source>Error updating concept</source>
        <translation>Error actualizando concepto</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="432"/>
        <source>Current month fits in the scheduled expense description.
Do you want the expense to be created in it?</source>
        <translation>El mes actual cumple la descripción para el gasto planificado.
¿Desea que el gasto sea creado en él?</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="443"/>
        <source>Error creating scheduled expense</source>
        <translation>Error creando el gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="454"/>
        <source>Error deleting scheduled expense</source>
        <translation>Error eliminando gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="474"/>
        <source>Current month fits in the scheduled expense description after the modification.
Do you want the expense to be created in it?</source>
        <translation>El mes actual cumple la descripción para el gasto planificado tras la modificación.
¿Desea que el gasto sea creado en él?</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="485"/>
        <source>Error updating scheduled expense</source>
        <translation>Error actualizando gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="510"/>
        <source>Error loading data interval</source>
        <translation>Error cargando datos de intervalo</translation>
    </message>
    <message>
        <location filename="../src/controller.cpp" line="520"/>
        <source>Error loading interval data</source>
        <translation>Error cargando datos de período</translation>
    </message>
</context>
<context>
    <name>DateChooserDialog</name>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="29"/>
        <source>Choose a date</source>
        <translation>Seleccione una fecha</translation>
    </message>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="80"/>
        <source>Done</source>
        <translation>Hecho</translation>
    </message>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="101"/>
        <source>Choose a month</source>
        <translation>Seleccione un mes</translation>
    </message>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="110"/>
        <source>Choose a year</source>
        <translation>Seleccione un año</translation>
    </message>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="115"/>
        <source>Minimum date is %1 %2</source>
        <translation>La fecha mínima es %1 de %2</translation>
    </message>
    <message>
        <location filename="../src/datechooserdialog.cpp" line="123"/>
        <source>Maximum date is %1 %2</source>
        <translation>La fecha máxima es %1 de %2</translation>
    </message>
</context>
<context>
    <name>ExpenseDetailsDialog</name>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="18"/>
        <source>Add new expense</source>
        <translation>Añadir nuevo gasto</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="95"/>
        <source>Day</source>
        <translation>Día</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="103"/>
        <source>Item</source>
        <translation>Concepto</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="114"/>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="117"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="123"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="41"/>
        <source>Expense details</source>
        <translation>Detalles de gasto</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="45"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="139"/>
        <source>Today</source>
        <translation>Hoy</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="141"/>
        <source>Yesterday</source>
        <translation>Ayer</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="143"/>
        <source>Tomorrow</source>
        <translation>Mañana</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="163"/>
        <source>Invalid day</source>
        <translation>Día inválido</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="177"/>
        <source>Choose a concept or enter a description</source>
        <translation>Seleccione un concepto o introduzca una descripción</translation>
    </message>
    <message>
        <location filename="../src/expensedetailsdialog.cpp" line="183"/>
        <source>Invalid amount</source>
        <translation>Cantidad inválida</translation>
    </message>
</context>
<context>
    <name>ExpensesList</name>
    <message>
        <location filename="../src/expenseslist.cpp" line="13"/>
        <source>Expenses</source>
        <translation>Gastos</translation>
    </message>
    <message>
        <location filename="../src/expenseslist.cpp" line="20"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="18"/>
        <source>Account: none selected</source>
        <translation>Cuenta: ninguna seleccionada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="34"/>
        <location filename="../src/mainwindow.cpp" line="55"/>
        <source>Budget</source>
        <translation>Presupuesto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="38"/>
        <location filename="../src/mainwindow.cpp" line="56"/>
        <source>Expenses</source>
        <translation>Gastos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="42"/>
        <source>Difference</source>
        <translation>Diferencia</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="48"/>
        <source>Add expense</source>
        <translation>Nuevo gasto</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="53"/>
        <source>Accounts</source>
        <translation>Cuentas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="54"/>
        <source>Items</source>
        <translation>Conceptos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="57"/>
        <source>Scheduled</source>
        <translation>Planificados</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="58"/>
        <source>Summary</source>
        <translation>Resumen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="94"/>
        <source>Account: %1</source>
        <translation>Cuenta: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="125"/>
        <source>accumulated view</source>
        <translation>vista acumulada</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="127"/>
        <source>daily view</source>
        <translation>vista diaria</translation>
    </message>
</context>
<context>
    <name>PeriodWindow</name>
    <message>
        <location filename="../src/periodwindow.cpp" line="35"/>
        <source>Months from</source>
        <translation>Meses desde</translation>
    </message>
    <message>
        <location filename="../src/periodwindow.cpp" line="43"/>
        <source>to</source>
        <translation>hasta</translation>
    </message>
    <message>
        <location filename="../src/periodwindow.cpp" line="51"/>
        <source>Update</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../src/periodwindow.cpp" line="63"/>
        <source>Choose a period start date</source>
        <translation>Seleccione una fecha de inicio para el período</translation>
    </message>
    <message>
        <location filename="../src/periodwindow.cpp" line="68"/>
        <source>Choose a period finish date</source>
        <translation>Seleccione una fecha de fin para el período</translation>
    </message>
    <message>
        <location filename="../src/periodwindow.cpp" line="74"/>
        <source>Start date must be prior to end date</source>
        <translation>La fecha de inicio debe ser anterior a la fecha de fin</translation>
    </message>
</context>
<context>
    <name>ScheduledDetailsDialog</name>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="19"/>
        <source>New scheduled expense</source>
        <translation>Nuevo gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="24"/>
        <location filename="../src/scheduleddetailsdialog.cpp" line="45"/>
        <location filename="../src/scheduleddetailsdialog.cpp" line="245"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="41"/>
        <source>Scheduled expense details</source>
        <translation>Detalles de gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="47"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="90"/>
        <source>Day</source>
        <translation>Día</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="97"/>
        <source>Repeat</source>
        <translation>Repetir</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="102"/>
        <source>Item</source>
        <translation>Concepto</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="113"/>
        <source>Amount</source>
        <translation>Cantidad</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="116"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="134"/>
        <source>Invalid day</source>
        <translation>Día inválido</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="148"/>
        <source>Choose a concept or enter a description</source>
        <translation>Seleccione un concepto o introduzca una descripción</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="154"/>
        <source>Invalid amount</source>
        <translation>Cantidad inválida</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="159"/>
        <source>Select at least one month for the expense</source>
        <translation>Seleccione al menos un mes para el gasto planificado</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="170"/>
        <source>Day %1 in month %2 is not a valid date</source>
        <translation>El día %1 de %2 no es una fecha válida</translation>
    </message>
    <message>
        <location filename="../src/scheduleddetailsdialog.cpp" line="215"/>
        <source>Select months to perform the expense</source>
        <translation>Seleccione los meses para realizar el gasto planificado</translation>
    </message>
</context>
<context>
    <name>ScheduledList</name>
    <message>
        <location filename="../src/scheduledlist.cpp" line="13"/>
        <source>Scheduled Expenses</source>
        <translation>Gastos planificados</translation>
    </message>
    <message>
        <location filename="../src/scheduledlist.cpp" line="20"/>
        <source>New</source>
        <translation>Nuevo</translation>
    </message>
</context>
<context>
    <name>SummaryWindow</name>
    <message>
        <location filename="../src/summarywindow.cpp" line="17"/>
        <source>Month Summary</source>
        <translation>Resumen de meses</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="20"/>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="22"/>
        <source>Items</source>
        <translation>Conceptos</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="42"/>
        <source>Period totals</source>
        <translation>Totales del período</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="43"/>
        <source>Budget</source>
        <translation>Presupuesto</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="46"/>
        <source>Expenses</source>
        <translation>Gastos</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="49"/>
        <source>Saved</source>
        <translation>Ahorro</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="53"/>
        <source>Period expenses</source>
        <translation>Gastos del período</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="54"/>
        <location filename="../src/summarywindow.cpp" line="65"/>
        <source>Minimum</source>
        <translation>Mínimo</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="57"/>
        <location filename="../src/summarywindow.cpp" line="68"/>
        <source>Maximum</source>
        <translation>Máximo</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="60"/>
        <location filename="../src/summarywindow.cpp" line="71"/>
        <source>Average</source>
        <translation>Media</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="64"/>
        <source>Period saves</source>
        <translation>Ahorro del período</translation>
    </message>
    <message>
        <location filename="../src/summarywindow.cpp" line="142"/>
        <source>Warning: there are no expenses stored in the selected period</source>
        <translation>Aviso: no hay gastos almacenados en el período seleccionado</translation>
    </message>
</context>
</TS>
